@@ -4,18 +4,21 @@ import xarray as xr
 
 from frites.conn import conn_io
 from frites.io import logger
-from frites.core import mi_nd_gg, copnorm_nd
+from frites.estimator import GCMIEstimator
 from frites.utils import parallel_func
 
 
-def conn_dfc(data, win_sample=None, times=None, roi=None, n_jobs=1, gcrn=False,
-             agg_ch=False, verbose=None):
+def conn_dfc(data, win_sample=None, times=None, roi=None, agg_ch=False,
+             estimator=None, gcrn=False, n_jobs=1, verbose=None):
     """Single trial Dynamic Functional Connectivity.
 
-    This function computes the Dynamic Functional Connectivity (DFC) using the
-    Gaussian Copula Mutual Information (GCMI). The DFC is computed across time
-    points for each trial. Note that the DFC can either be computed on windows
-    manually defined or on sliding windows.
+    This function computes the pairwise Dynamic Functional Connectivity (DFC)
+    by estimating the statistical dependencies between time-series (possibly on
+    sliding windows) and at the single-trial level using a measure of
+    information. By default, if no estimator are provided the information
+    shared between the time-series of two brain regions is estimated using the
+    Gaussian-Copula Mutual Information (GCMI). However, other estimators can be
+    provided (e.g correlation, distance correlation etc.)
 
     Parameters
     ----------
@@ -37,20 +40,25 @@ def conn_dfc(data, win_sample=None, times=None, roi=None, n_jobs=1, gcrn=False,
     roi : array_like | None
         ROI names of a single subject. If the input is an xarray, the
         name of the ROI dimension can be provided
-    n_jobs : int | 1
-        Number of jobs to use for parallel computing (use -1 to use all
-        jobs). The parallel loop is set at the pair level.
-    gcrn : bool | False
-        Specify if the Gaussian Copula Rank Normalization should be applied.
-        If the data are normalized (e.g z-score) this parameter can be set to
-        False because the data can be considered as gaussian over time.
     agg_ch : bool | False
         In case there are multiple electrodes, channels, contacts or sources
         inside a brain region, specify how the data has to be aggregated. Use
         either :
 
             * agg_ch=False : compute the pairwise DFC aross all possible pairs
-            * agg_ch=True : compute the multivariate MI
+            * agg_ch=True : compute the multivariate information
+
+        Note that feature is only available for measures of information
+        supporting multivariate computations.
+    estimator : frites.estimator | None
+        Estimator in order to measure the amount of information shared between
+        two time-series coming from two distinct brain regions. Note that if
+        you want to privide an estimator, be sure that it is made for
+        continuous variables (mi_type='cc'). By default the Gaussian-Copula
+        mutual-information is used.
+    n_jobs : int | 1
+        Number of jobs to use for parallel computing (use -1 to use all
+        jobs). The parallel loop is set at the pair level.
 
     Returns
     -------
@@ -71,50 +79,51 @@ def conn_dfc(data, win_sample=None, times=None, roi=None, n_jobs=1, gcrn=False,
     # extract variables
     x, trials, attrs = data.data, data['y'].data, cfg['attrs']
     win_sample, win_times = cfg['win_sample'], cfg['win_times']
-    n_win = win_sample.shape[0]
     x_s, x_t = cfg['x_s'], cfg['x_t']
     roi_p, roi_idx = cfg['roi_p'], cfg['roi_idx']
     n_pairs = len(x_s)
 
+    # estimator
+    if estimator is None:
+        estimator = GCMIEstimator(
+            mi_type='cc', copnorm=False, biascorrect=False, demeaned=False,
+            verbose=verbose)
+    assert estimator.settings['mi_type'] == 'cc', (
+        "Estimator should extract information between two continuous "
+        "variables (mi_type='cc')")
+    fcn = estimator.get_function()
+
     # __________________________________ DFC __________________________________
+    # function to put in parallel
+
+    def para_dfc(i_s, i_t):
+        dfc = np.zeros((len(trials), 1, len(win_sample)))
+        x_s, x_t = x[:, roi_idx[i_s], :], x[:, roi_idx[i_t], :]
+        for n_w, (w_s, w_e) in enumerate(win_sample):
+            dfc[:, 0, n_w] = fcn(x_s[..., w_s:w_e], x_t[..., w_s:w_e])
+        return dfc
+
     # prepare parallel function
-    n_jobs = 1 if n_win == 1 else n_jobs
-    parallel, p_fun = parallel_func(_conn_dfc, n_jobs=n_jobs, verbose=verbose,
-                                    total=n_win, mesg='Estimating DFC')
+    n_jobs = 1 if n_pairs == 1 else n_jobs
+    parallel, p_fun = parallel_func(para_dfc, n_jobs=n_jobs, verbose=verbose,
+                                    total=n_pairs, mesg='Estimating DFC')
 
     logger.info(f'Computing DFC between {n_pairs} pairs (gcrn={gcrn})')
 
     # compute dfc
-    dfc = parallel(p_fun(
-        x[:, :, w[0]:w[1]], x_s, x_t, roi_idx, gcrn) for w in win_sample)
-    dfc = np.stack(dfc, 2)
+    dfc = parallel(p_fun(i_s, i_t) for i_s, i_t in zip(x_s, x_t))
+    dfc = np.concatenate(dfc, axis=1)
 
-    # ________________________________ OUPUTS _________________________________
+    # ________________________________ OUTPUTS ________________________________
     # dataarray conversion
-    dfc = xr.DataArray(dfc, dims=('trials', 'roi', 'times'), name='dfc',
-                       coords=(trials, roi_p, win_times))
+    dfc = xr.DataArray(dfc, dims=('trials', 'roi', 'times'),
+                       coords=(trials, roi_p, win_times),
+                       name=f'DFC ({estimator.name})')
 
     # add the windows used in the attributes
     cfg = dict(
         win_sample=np.r_[tuple(win_sample)], win_times=np.r_[tuple(win_times)],
-        agg_ch=agg_ch, type='dfc')
+        agg_ch=str(agg_ch), type='dfc', estimator=estimator.name)
     dfc.attrs = {**cfg, **attrs}
 
     return dfc
-
-
-def _conn_dfc(x_w, x_s, x_t, roi_idx, gcrn):
-    """Parallel function for computing DFC."""
-    dfc = np.zeros((x_w.shape[0], len(x_s)))
-    # copnorm data only once
-    if gcrn:
-        x_w = copnorm_nd(x_w, axis=2)
-    # compute dfc
-    for n_p, (s, t) in enumerate(zip(x_s, x_t)):
-        # select sources and targets time-series
-        _x_s = x_w[:, roi_idx[s], :]
-        _x_t = x_w[:, roi_idx[t], :]
-        # compute mi between time-series
-        dfc[:, n_p] = mi_nd_gg(_x_s, _x_t, traxis=-1, mvaxis=-2,
-                               shape_checking=False)
-    return dfc
